# Parse SPLConqueror measurements.xml file.

import xml.etree.ElementTree as ET
import pandas as pd
import os

def parse_df(pathname):
    '''Parse a mesurement file.  Return a pandas data frame [Configuration, Value].
    '''
    msmt = parse(pathname)
    configs, values = zip(*msmt)
    return pd.DataFrame({'Configuration':configs, 'Value':values})

def parse(pathname):
    ''' Parse a mesurement file.  Return a list of typels: (configuration, measured_value).
    '''
    measurements = []
    tree = ET.parse(pathname)
    root = tree.getroot()
    for measurement in root.findall('row'):
        if measurement[0].text:
            configuration = frozenset([o.strip() for o in measurement[0].text.split(',') if o.strip() != ''])
        else:
            configuration = ''
        value = float(measurement[1].text.replace(',', '.'))
        measurements.append((configuration, value))
    return measurements

def parse_df_all(system_ids, experiment_ids, base_dir):
    MSMTFILE = 'all_measurements.xml'
    data_msmt = {}
    for sysid in system_ids:
        sysexpids = [sysid+'_'+x for x in experiment_ids]
        pathname = os.path.sep.join([base_dir, sysid, MSMTFILE])
        msmt = parse_df(pathname)
        for sysexpid in sysexpids:
            data_msmt[sysexpid] = msmt
    return data_msmt

if __name__ == '__main__':
    pass
